@@ -98,9 +98,6 @@ class OptsTestCase(base.StoreBaseTest):
             'rados_connect_timeout',
             'rootwrap_config',
             'swift_store_expire_soon_interval',
-            'sheepdog_store_address',
-            'sheepdog_store_chunk_size',
-            'sheepdog_store_port',
             'swift_store_admin_tenants',
             'swift_store_auth_address',
             'swift_store_cacert',
